Package {rsf}


Type: Package
Title: Report of Statistical Findings in Quarto
Version: 1.0.0
Description: A report of statistical findings (RSF) project template is generated using a Quarto book.
License: MIT + file LICENSE
URL: https://github.com/dchiu911/rsf/, https://dchiu911.github.io/rsf/
BugReports: https://github.com/dchiu911/rsf/issues
Imports: gert, renv
Encoding: UTF-8
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-09-16 22:24:49 UTC; derekchiu
Author: Derek Chiu [aut, cre]
Maintainer: Derek Chiu <dchiu@bccrc.ca>
Repository: CRAN
Date/Publication: 2026-09-16 22:40:02 UTC

rsf: Report of Statistical Findings in Quarto

Description

logo

A report of statistical findings (RSF) project template is generated using a Quarto book.

Author(s)

Maintainer: Derek Chiu dchiu@bccrc.ca

Authors:

See Also

Useful links:


Use RSF project template

Description

Create a new Quarto book R project using the RSF template. Intended for use in RStudio menu, not interactively.

Usage

use_rsf(path, ...)

Arguments

path

project path

...

project configurations supported:

Details

This function is called when the user selects File > New Project > New Directory > Report of Statistical Findings using Quarto. The directory name can be specified, and the user can choose to initialize the project as a git repository and/or use with renv.

Examples

## Not run: 
# Don't run interactively. Use RStudio Create Project menu.
use_rsf(path = ".")

## End(Not run)